package MT::Plugin::HalfMonthlyArchives;
use strict;
use base qw( MT::Plugin );

use MT;

our $VERSION = '0.03';

my $plugin = __PACKAGE__->new({
    id => 'half_monthly_archives',
    name => 'HalfMonthlyArchives',
    description => q(<MT_TRANS phrase="A plugin for building Half Monthly Archives">),
    doc_link => 'https://web-conte.com/blue/201806/03_0204.php',
    author_name => 'SOMA Hitoshi',
    author_link => 'https://web-conte.com/',
    version => $VERSION,
    l10n_class => 'HalfMonthlyArchives::L10N',
    system_config_template => 'system_config.tmpl',
    settings => new MT::PluginSettings([
        [ 'first_half_label', { Default => 'a', Scope => 'system' } ],
        [ 'last_half_label', { Default => 'b', Scope => 'system' } ],
    ]),
});
MT->add_plugin($plugin);

sub instance { $plugin }

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        tags => {
            function => {
                ArchiveHalfMonthLabel => \&archive_half_month_label,
            },
        },
        archive_types => {
            'HalfMonthly'          => 'HalfMonthlyArchives::HalfMonthly',
        },
    });
}

# MTArchiveHalfMonth tag
use HalfMonthlyArchives::Util qw( first_half_label last_half_label ts2half );
sub archive_half_month_label {
    my ($ctx, %param) = @_;
    my $ts = $ctx->{current_timestamp};
    my $tag = $ctx->stash('tag');
    my $label;
    return $ctx->error(MT->translate("You used an [_1] tag without a date context set up.", "MT$tag"))
        unless defined $ts;
    if (ts2half($ts) == 1) {
        $label = first_half_label;
    } else {
        $label = last_half_label;
    }
    return $label;
}

1;
